==> nextcloud-app-calendar-1.5.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/it.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Calendario",
    "%s has published the calendar \"%s\"" : "%s ha pubblicato il calendario \"%s\"",
    "Too many redirects. Aborting ..." : "Troppe redirezioni. Interruzione in corso...",
    "The remote server did not give us access to the calendar (HTTP {%s} error)" : "Il server remoto ha negato l'accesso al calendario (errore HTTP {%s})",
    "Error connecting to remote server" : "Errore durante la connessione al server remoto",
    "Error requesting resource on remote server. This could possible be related to a certificate mismatch" : "Errore durante la richiesta di una risorsa al server remoto. Ciò potrebbe essere dovuto da una mancata corrispondenza del certificato",
    "Error requesting resource on remote server" : "Errore durante la richiesta di una risorsa al server remoto",
    "Individual" : "Singolo",
    "Group" : "Gruppo",
    "Resource" : "Risorsa",
    "Room" : "Stanza",
    "Unknown" : "Sconosciuto",
    "Required" : "Richiesto",
    "Optional" : "Facoltativo",
    "Does not attend" : "Non partecipa",
    "{name} ({email})" : "{name} ({email})",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "Sei in un fuso orario sconosciuto ({tz}), ripiego su UTC",
    "Please create a calendar first." : "Crea prima un calendario.",
    "New event" : "Nuovo evento",
    "CalDAV address for clients" : "Indirizzo CalDAV per i client",
    "Error saving WebCal-calendar" : "Errore durante il salvataggio del calendario WebCal",
    "WebDAV address for subscriptions" : "Indirizzo WebDAV per le sottoscrizioni",
    "EMail has been sent." : "Il messaggio è stata inviato.",
    "There was an issue while sending your EMail." : "C'è stato un problema durante l'invio del tuo messaggio.",
    "group" : "gruppo",
    "Details" : "Dettagli",
    "Attendees" : "Partecipanti",
    "Reminders" : "Promemoria",
    "Repeating" : "Ripetizione",
    "When shared show full event" : "Se condiviso, mostra l'evento completo",
    "When shared show only busy" : "Se condiviso, mostra solo occupato",
    "When shared hide this event" : "Se condiviso, nascondi questo evento",
    "Confirmed" : "Confermato",
    "Tentative" : "Provvisorio",
    "Cancelled" : "Annullato",
    "Please add a title!" : "Aggiungi un titolo!",
    "Please select a calendar!" : "Seleziona un calendario!",
    "Global" : "Globale",
    "None" : "Nessuno",
    "Every day" : "Ogni giorno",
    "Every week" : "Ogni settimana",
    "Every month" : "Ogni mese",
    "Every year" : "Ogni anno",
    "never" : "mai",
    "after" : "dopo",
    "How about getting started by importing some calendars?" : "Perché non inizi importando qualche calendario?",
    "At time of event" : "Al momento dell'evento",
    "5 minutes before" : "5 minuti prima",
    "10 minutes before" : "10 minuti prima",
    "15 minutes before" : "15 minuti prima",
    "30 minutes before" : "30 minuti prima",
    "1 hour before" : "1 ora prima",
    "2 hours before" : "2 ore prima",
    "Custom" : "Personalizzato",
    "Audio" : "Audio",
    "E Mail" : "Posta elettronica",
    "Pop up" : "Finestra a comparsa",
    "sec" : "sec",
    "min" : "min",
    "hours" : "ore",
    "days" : "giorni",
    "week" : "settimana",
    "before" : "prima",
    "start" : "inizia",
    "end" : "finisce",
    "Editing reminders of unknown type not supported." : "La modifica di promemoria di tipo sconosciuto non è supportata.",
    "Week {number} of {year}" : "Settimana {number} del {year}",
    "Successfully imported" : "Importato correttamente",
    "Partially imported, 1 failure" : "Importato parzialmente, 1 problema",
    "Partially imported, {n} failures" : "Importato parzialmente, {n} problemi",
    "Audio alarm" : "Avviso sonoro",
    "Pop-up" : "Finestra a comparsa",
    "E-Mail" : "Posta elettronica",
    "{type} {time} before the event starts" : "{type} {time} prima dell'inizio dell'evento",
    "{type} {time} before the event ends" : "{type} {time} prima della fine dell'evento",
    "{type} {time} after the event starts" : "{type} {time} dopo l'inizio dell'evento",
    "{type} {time} after the event ends" : "{type} {time} dopo la fine dell'evento",
    "{type} at the event's start" : "{type} all'inizio dell'evento",
    "{type} at the event's end" : "{type} alla fine dell'evento",
    "{type} at {time}" : "{type} alle {time}",
    "{calendar} shared by {owner}" : "{calendar} condiviso da {owner}",
    "Please enter a valid WebCal-URL" : "Digita un URL WebCal valido",
    "Severe error in webcal proxy. Please contact administrator for more information." : "Errore grave nel proxy webcal. Contatta l'amministratore per ulteriori informazioni.",
    "Title of the Event" : "Titolo dell'evento",
    "starts" : "inizia",
    "ends" : "finisce",
    "All day Event" : "Evento di un giorno intero",
    "Delete" : "Elimina",
    "Cancel" : "Annulla",
    "More ..." : "Altro...",
    "Create" : "Crea",
    "Update" : "Aggiorna",
    "Close" : "Chiudi",
    "Location" : "Posizione",
    "Description" : "Descrizione",
    "Event status" : "Stato dell'evento",
    "Visibility when sharing" : "Visibilità in caso di condivisione",
    "Export" : "Esporta",
    "%s has published the calendar %s" : "%s ha pubblicato il calendario %s",
    "Hello," : "Ciao,",
    "We wanted to inform you that %s has published the calendar {boldstart}%s{boldend}." : "Ti vogliamo informare che %s ha pubblicato il calendario {boldstart}%s{boldend}.",
    "Click here to access it" : "Fai clic qui per accedere",
    "Cheers!" : "Evviva!",
    "We wanted to inform you that %s has published the calendar %s." : "Ti vogliamo informare che %s ha pubblicato il calendario %s.",
    "Click on the link below to access it" : "Fai clic sul collegamento sotto per accedere",
    "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "A causa di un bug a monte, il calendario non è attualmente in grado di fornire supporto per la funzionalità di asset pipeline.",
    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Contatta il tuo amministratore e chiedigli di disabilitare l'opzione di configurazione \"asset-pipeline.enabled\".",
    "Day" : "Giorno",
    "Week" : "Settimana",
    "Month" : "Mese",
    "Today" : "Oggi",
    "Some events in this calendar are broken. Please check the JS console for more info." : "Alcuni eventi in questo calendario sono danneggiati. Controlla la console JS per ulteriori informazioni.",
    "Share Calendar" : "Condividi calendario",
    "Shared" : "Condiviso",
    "More" : "Altro",
    "Edit" : "Modifica",
    "Link" : "Collegamento",
    "iCal link" : "Collegamento iCal",
    "Download" : "Scarica",
    "Share with users or groups" : "Condividi con utenti o gruppi",
    "can edit" : "può modificare",
    "Share link" : "Condividi il collegamento",
    "Public access" : "Accesso pubblico",
    "Email link to person" : "Invia il collegamento alla persona tramite email",
    "Send" : "Invia",
    "New Calendar" : "Nuovo calendario",
    "Name" : "Nome",
    "New Subscription" : "Nuova sottoscrizione",
    "Go back" : "Indietro",
    "Go forward" : "Avanti",
    "Edit event" : "Modifica evento",
    "Delete Event" : "Elimina evento",
    "Save Event" : "Salva evento",
    "Time" : "Ora",
    "Type" : "Tipo",
    "Relative" : "Relativo",
    "Absolute" : "Assoluto",
    "Repeat" : "Ripeti",
    "times every" : "volte ogni",
    "Add" : "Aggiungi",
    "E-Mail address of attendee" : "Indirizzo email del partecipante",
    "Please add your email address in the personal settings in order to add attendees." : "Aggiungi il tuo indirizzo email nelle impostazioni personali per aggiungere i partecipanti.",
    "from" : "da",
    "to" : "a",
    "This event's repeating rule is not supported yet." : "Questa regola di ripetizione dell'evento non è ancora supportata.",
    "Support for advanced rules will be added with subsequent updates." : "Il supporto per le regole avanzate sarà aggiunto con aggiornamenti successivi.",
    "Reset repeating rule" : "Ripristina la regola di ripetizione",
    "Repeat every ..." : "Ripeti ogni...",
    "end repeat ..." : "fine della ripetizione...",
    "times" : "volte",
    "Import Calendars" : "Importa calendari",
    "Import canceled" : "Importazione annullata",
    "Analyzing calendar" : "Analisi del calendario",
    "The file contains objects incompatible with the selected calendar" : "Il file contiene oggetti non compatibili con il calendario selezionato",
    "New calendar" : "Nuovo calendario",
    "File is empty" : "Il file è vuoto",
    "Import scheduled" : "Importa pianificati",
    "Subscribe & embed" : "Sottoscrivi e integra",
    "Publish URL" : "Pubblica URL",
    "Iframe to integrate" : "Iframe da integrare",
    "Settings & import" : "Impostazioni e importazione",
    "Skip simple event editor" : "Salta l'editor semplice degli eventi",
    "Show week numbers" : "Mostra i numeri delle settimane",
    "Import calendar" : "Importa calendario",
    "No Calendars selected for import" : "Nessun calendario selezionato per l'importazione",
    "Primary CalDAV address" : "Indirizzo CalDAV principale",
    "iOS/OS X CalDAV address" : "Indirizzo CalDAV iOS/OS X"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-calendar-1.5.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/it.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Calendario",
    "%s has published the calendar \"%s\"" : "%s ha pubblicato il calendario \"%s\"",
    "Too many redirects. Aborting ..." : "Troppe redirezioni. Interruzione in corso...",
    "The remote server did not give us access to the calendar (HTTP {%s} error)" : "Il server remoto ha negato l'accesso al calendario (errore HTTP {%s})",
    "Error connecting to remote server" : "Errore durante la connessione al server remoto",
    "Error requesting resource on remote server. This could possible be related to a certificate mismatch" : "Errore durante la richiesta di una risorsa al server remoto. Ciò potrebbe essere dovuto da una mancata corrispondenza del certificato",
    "Error requesting resource on remote server" : "Errore durante la richiesta di una risorsa al server remoto",
    "Individual" : "Singolo",
    "Group" : "Gruppo",
    "Resource" : "Risorsa",
    "Room" : "Stanza",
    "Unknown" : "Sconosciuto",
    "Required" : "Richiesto",
    "Optional" : "Facoltativo",
    "Does not attend" : "Non partecipa",
    "{name} ({email})" : "{name} ({email})",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "Sei in un fuso orario sconosciuto ({tz}), ripiego su UTC",
    "Please create a calendar first." : "Crea prima un calendario.",
    "New event" : "Nuovo evento",
    "CalDAV address for clients" : "Indirizzo CalDAV per i client",
    "Error saving WebCal-calendar" : "Errore durante il salvataggio del calendario WebCal",
    "WebDAV address for subscriptions" : "Indirizzo WebDAV per le sottoscrizioni",
    "EMail has been sent." : "Il messaggio è stata inviato.",
    "There was an issue while sending your EMail." : "C'è stato un problema durante l'invio del tuo messaggio.",
    "group" : "gruppo",
    "Details" : "Dettagli",
    "Attendees" : "Partecipanti",
    "Reminders" : "Promemoria",
    "Repeating" : "Ripetizione",
    "When shared show full event" : "Se condiviso, mostra l'evento completo",
    "When shared show only busy" : "Se condiviso, mostra solo occupato",
    "When shared hide this event" : "Se condiviso, nascondi questo evento",
    "Confirmed" : "Confermato",
    "Tentative" : "Provvisorio",
    "Cancelled" : "Annullato",
    "Please add a title!" : "Aggiungi un titolo!",
    "Please select a calendar!" : "Seleziona un calendario!",
    "The event ends before it starts!" : "L'evento termina prima del suo inizio!",
    "Global" : "Globale",
    "None" : "Nessuno",
    "Every day" : "Ogni giorno",
    "Every week" : "Ogni settimana",
    "Every month" : "Ogni mese",
    "Every year" : "Ogni anno",
    "never" : "mai",
    "after" : "dopo",
    "How about getting started by importing some calendars?" : "Perché non inizi importando qualche calendario?",
    "At time of event" : "Al momento dell'evento",
    "5 minutes before" : "5 minuti prima",
    "10 minutes before" : "10 minuti prima",
    "15 minutes before" : "15 minuti prima",
    "30 minutes before" : "30 minuti prima",
    "1 hour before" : "1 ora prima",
    "2 hours before" : "2 ore prima",
    "Custom" : "Personalizzato",
    "Audio" : "Audio",
    "E Mail" : "Posta elettronica",
    "Pop up" : "Finestra a comparsa",
    "sec" : "sec",
    "min" : "min",
    "hours" : "ore",
    "days" : "giorni",
    "week" : "settimana",
    "before" : "prima",
    "start" : "inizia",
    "end" : "finisce",
    "Editing reminders of unknown type not supported." : "La modifica di promemoria di tipo sconosciuto non è supportata.",
    "Week {number} of {year}" : "Settimana {number} del {year}",
    "Successfully imported" : "Importato correttamente",
    "Partially imported, 1 failure" : "Importato parzialmente, 1 problema",
    "Partially imported, {n} failures" : "Importato parzialmente, {n} problemi",
    "Audio alarm" : "Avviso sonoro",
    "Pop-up" : "Finestra a comparsa",
    "E-Mail" : "Posta elettronica",
    "{type} {time} before the event starts" : "{type} {time} prima dell'inizio dell'evento",
    "{type} {time} before the event ends" : "{type} {time} prima della fine dell'evento",
    "{type} {time} after the event starts" : "{type} {time} dopo l'inizio dell'evento",
    "{type} {time} after the event ends" : "{type} {time} dopo la fine dell'evento",
    "{type} at the event's start" : "{type} all'inizio dell'evento",
    "{type} at the event's end" : "{type} alla fine dell'evento",
    "{type} at {time}" : "{type} alle {time}",
    "{calendar} shared by {owner}" : "{calendar} condiviso da {owner}",
    "Please enter a valid WebCal-URL" : "Digita un URL WebCal valido",
    "Severe error in webcal proxy. Please contact administrator for more information." : "Errore grave nel proxy webcal. Contatta l'amministratore per ulteriori informazioni.",
    "Title of the Event" : "Titolo dell'evento",
    "Starts" : "Inizia",
    "Ends" : "Finisce",
    "All day Event" : "Evento di un giorno intero",
    "Delete" : "Elimina",
    "Cancel" : "Annulla",
    "More ..." : "Altro...",
    "Create" : "Crea",
    "Update" : "Aggiorna",
    "Close" : "Chiudi",
    "Location" : "Posizione",
    "Description" : "Descrizione",
    "Event status" : "Stato dell'evento",
    "Visibility when sharing" : "Visibilità in caso di condivisione",
    "Export" : "Esporta",
    "%s has published the calendar %s" : "%s ha pubblicato il calendario %s",
    "Hello," : "Ciao,",
    "We wanted to inform you that %s has published the calendar {boldstart}%s{boldend}." : "Ti vogliamo informare che %s ha pubblicato il calendario {boldstart}%s{boldend}.",
    "Click here to access it" : "Fai clic qui per accedere",
    "Cheers!" : "Evviva!",
    "We wanted to inform you that %s has published the calendar %s." : "Ti vogliamo informare che %s ha pubblicato il calendario %s.",
    "Click on the link below to access it" : "Fai clic sul collegamento sotto per accedere",
    "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "A causa di un bug a monte, il calendario non è attualmente in grado di fornire supporto per la funzionalità di asset pipeline.",
    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Contatta il tuo amministratore e chiedigli di disabilitare l'opzione di configurazione \"asset-pipeline.enabled\".",
    "Day" : "Giorno",
    "Week" : "Settimana",
    "Month" : "Mese",
    "Today" : "Oggi",
    "Some events in this calendar are broken. Please check the JS console for more info." : "Alcuni eventi in questo calendario sono danneggiati. Controlla la console JS per ulteriori informazioni.",
    "Share Calendar" : "Condividi calendario",
    "Shared" : "Condiviso",
    "More" : "Altro",
    "Edit" : "Modifica",
    "Link" : "Collegamento",
    "iCal link" : "Collegamento iCal",
    "Download" : "Scarica",
    "Share with users or groups" : "Condividi con utenti o gruppi",
    "can edit" : "può modificare",
    "Share link" : "Condividi il collegamento",
    "Public access" : "Accesso pubblico",
    "Email link to person" : "Invia il collegamento alla persona tramite email",
    "Send" : "Invia",
    "New Calendar" : "Nuovo calendario",
    "Name" : "Nome",
    "New Subscription" : "Nuova sottoscrizione",
    "Go back" : "Indietro",
    "Go forward" : "Avanti",
    "Edit event" : "Modifica evento",
    "Delete Event" : "Elimina evento",
    "Save Event" : "Salva evento",
    "Time" : "Ora",
    "Type" : "Tipo",
    "Relative" : "Relativo",
    "Absolute" : "Assoluto",
    "Repeat" : "Ripeti",
    "times every" : "volte ogni",
    "Add" : "Aggiungi",
    "E-Mail address of attendee" : "Indirizzo email del partecipante",
    "Please add your email address in the personal settings in order to add attendees." : "Aggiungi il tuo indirizzo email nelle impostazioni personali per aggiungere i partecipanti.",
    "from" : "da",
    "to" : "a",
    "This event's repeating rule is not supported yet." : "Questa regola di ripetizione dell'evento non è ancora supportata.",
    "Support for advanced rules will be added with subsequent updates." : "Il supporto per le regole avanzate sarà aggiunto con aggiornamenti successivi.",
    "Reset repeating rule" : "Ripristina la regola di ripetizione",
    "Repeat every ..." : "Ripeti ogni...",
    "end repeat ..." : "fine della ripetizione...",
    "times" : "volte",
    "Import Calendars" : "Importa calendari",
    "Import canceled" : "Importazione annullata",
    "Analyzing calendar" : "Analisi del calendario",
    "The file contains objects incompatible with the selected calendar" : "Il file contiene oggetti non compatibili con il calendario selezionato",
    "New calendar" : "Nuovo calendario",
    "File is empty" : "Il file è vuoto",
    "Import scheduled" : "Importa pianificati",
    "Publish URL" : "Pubblica URL",
    "Settings & import" : "Impostazioni e importazione",
    "Skip simple event editor" : "Salta l'editor semplice degli eventi",
    "Show week numbers" : "Mostra i numeri delle settimane",
    "Import calendar" : "Importa calendario",
    "No Calendars selected for import" : "Nessun calendario selezionato per l'importazione",
    "Primary CalDAV address" : "Indirizzo CalDAV principale",
    "iOS/OS X CalDAV address" : "Indirizzo CalDAV iOS/OS X"
},
"nplurals=2; plural=(n != 1);");
